@@ -114,6 +114,22 @@ DIAG_UNDEFINED_DOC_NAME               =
 '未定義的類型或別名 `{}`。'
 DIAG_UNDEFINED_DOC_PARAM              =
 '指向了未定義的參數 `{}`。'
+DIAG_MISSING_GLOBAL_DOC_COMMENT       = -- TODO: need translate!
+'Missing comment for global function `{}`.'
+DIAG_MISSING_GLOBAL_DOC_PARAM         = -- TODO: need translate!
+'Missing @param annotation for parameter `{}` in global function `{}`.'
+DIAG_MISSING_GLOBAL_DOC_RETURN        = -- TODO: need translate!
+'Missing @return annotation at index `{}` in global function `{}`.'
+DIAG_MISSING_LOCAL_EXPORT_DOC_COMMENT = -- TODO: need translate!
+'Missing comment for exported local function `{}`.'
+DIAG_MISSING_LOCAL_EXPORT_DOC_PARAM   = -- TODO: need translate!
+'Missing @param annotation for parameter `{}` in exported local function `{}`.'
+DIAG_MISSING_LOCAL_EXPORT_DOC_RETURN  = -- TODO: need translate!
+'Missing @return annotation at index `{}` in exported local function `{}`.'
+DIAG_INCOMPLETE_SIGNATURE_DOC_PARAM   = -- TODO: need translate!
+'Incomplete signature. Missing @param annotation for parameter `{}`.'
+DIAG_INCOMPLETE_SIGNATURE_DOC_RETURN  = -- TODO: need translate!
+'Incomplete signature. Missing @return annotation at index `{}`.'
 DIAG_UNKNOWN_DIAG_CODE                =
 '未知的診斷代碼 `{}`。'
 DIAG_CAST_LOCAL_TYPE                  =
@@ -150,6 +166,16 @@ DIAG_INVISIBLE_PROTECTED              = -- TODO: need translate!
 'Field `{field}` is protected, it can only be accessed in class `{class}` and its subclasses.'
 DIAG_INVISIBLE_PACKAGE                = -- TODO: need translate!
 'Field `{field}` can only be accessed in same file `{uri}`.'
+DIAG_GLOBAL_ELEMENT                  = -- TODO: need translate!
+'Element is global.'
+DIAG_MISSING_FIELDS                   = -- TODO: need translate!
+'Missing required fields in type `{1}`: {2}'
+DIAG_INJECT_FIELD                     = -- TODO: need translate!
+'Fields cannot be injected into the reference of `{class}` for `{field}`. {fix}'
+DIAG_INJECT_FIELD_FIX_CLASS           = -- TODO: need translate!
+'To do so, use `---@class` for `{node}`.'
+DIAG_INJECT_FIELD_FIX_TABLE           = -- TODO: need translate!
+'如要允许注入，请在定义中添加 `{fix}` 。'
 
 MWS_NOT_SUPPORT         =
 '{} 目前還不支援多工作目錄，我可能需要重新啟動才能支援新的工作目錄...'
@@ -177,9 +203,9 @@ WORKSPACE_DIAGNOSTIC      =
 WORKSPACE_SKIP_HUGE_FILE  =
 '出於效能考慮，已停止對此檔案解析：{}'
 WORKSPACE_NOT_ALLOWED     =
-'你的工作目錄被設定為了 `{}` ，Lua語言伺服拒絕載入此目錄，請檢查你的設定檔。[了解更多](https://github.com/LuaLS/lua-language-server/wiki/FAQ#why-is-the-server-scanning-the-wrong-folder)'
-WORKSPACE_SCAN_TOO_MUCH   =
-'已掃描了超過 {} 個檔案，目前掃描的目錄為 `{}`，請確認設定檔是否正確。'
+'你的工作目錄被設定為了 `{}` ，Lua語言伺服拒絕載入此目錄，請檢查你的設定檔。[了解更多](https://luals.github.io/wiki/faq#why-is-the-server-scanning-the-wrong-folder)'
+WORKSPACE_SCAN_TOO_MUCH   = -- TODO: need translate!
+'已掃描了超過 {} 個檔案，目前掃描的目錄為 `{}`. Please see the [FAQ](https://luals.github.io/wiki/faq#how-can-i-improve-startup-speeds) to see how you can include fewer files. It is also possible that your [configuration is incorrect](https://luals.github.io/wiki/faq#why-is-the-server-scanning-the-wrong-folder).'
 
 PARSER_CRASH            =
 '語法解析崩潰了！遺言：{}'
@@ -281,6 +307,8 @@ PARSER_NEED_PAREN         = -- TODO: need translate!
 '需要添加一对括号。'
 PARSER_NESTING_LONG_MARK  = -- TODO: need translate!
 'Nesting of `[[...]]` is not allowed in Lua 5.1 .'
+PARSER_LOCAL_LIMIT        = -- TODO: need translate!
+'Only 200 active local variables and upvalues can be existed at the same time.'
 PARSER_LUADOC_MISS_CLASS_NAME           =
 '缺少類別名稱。'
 PARSER_LUADOC_MISS_EXTENDS_SYMBOL       =
@@ -428,6 +456,8 @@ ACTION_ADD_DICT         =
 '添加 \'{}\' 到工作區字典'
 ACTION_FIX_ADD_PAREN    = -- TODO: need translate!
 '添加括号。'
+ACTION_AUTOREQUIRE      = -- TODO: need translate!
+"Import '{}' as {}"
 
 COMMAND_DISABLE_DIAG       =
 '停用診斷'
@@ -528,7 +558,7 @@ WINDOW_APPLY_SETTING             =
 WINDOW_CHECK_SEMANTIC            =
 '如果你正在使用市場中的顏色主題，你可能需要同時修改 `editor.semanticHighlighting.enabled` 選項為 `true` 才會使語義著色生效。'
 WINDOW_TELEMETRY_HINT            =
-'請允許發送匿名的使用資料與錯誤報告，幫助我們進一步完善此延伸模組。在[此處](https://github.com/LuaLS/lua-language-server/wiki/Home#privacy)閱讀我們的隱私聲明。'
+'請允許發送匿名的使用資料與錯誤報告，幫助我們進一步完善此延伸模組。在[此處](https://luals.github.io/privacy/#language-server)閱讀我們的隱私聲明。'
 WINDOW_TELEMETRY_ENABLE          =
 '允許'
 WINDOW_TELEMETRY_DISABLE         =
@@ -616,8 +646,12 @@ CLI_CHECK_INITING =
 '正在初始化...'
 CLI_CHECK_SUCCESS =
 '診斷完成，沒有發現問題'
+CLI_CHECK_PROGRESS = -- TODO: need translate!
+'Found {} problems in {} files'
 CLI_CHECK_RESULTS =
 '診斷完成，共有 {} 個問題，請查看 {}'
+CLI_CHECK_MULTIPLE_WORKERS = -- TODO: need translate!
+'Starting {} worker tasks, progress output will be disabled. This may take a few minutes.'
 CLI_DOC_INITING   = -- TODO: need translate!
 'Loading documents ...'
 CLI_DOC_DONE      = -- TODO: need translate!
@@ -673,7 +707,7 @@ LUADOC_DESC_CLASS =
 Manager = {}
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#class)
+[檢視文件](https://luals.github.io/wiki/annotations#class)
 ]=]
 LUADOC_DESC_TYPE =
 [=[
@@ -724,7 +758,7 @@ local x --x[""] is true
 local myFunction
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#types-and-type)
+[檢視文件](https://luals.github.io/wiki/annotations#type)
 ]=]
 LUADOC_DESC_ALIAS =
 [=[
@@ -774,7 +808,7 @@ local enums = {
 ---| `enums.CLOSE`
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#alias)
+[檢視文件](https://luals.github.io/wiki/annotations#alias)
 ]=]
 LUADOC_DESC_PARAM =
 [=[
@@ -799,7 +833,7 @@ function get(url, headers, timeout) end
 function concat(base, ...) end
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#param)
+[檢視文件](https://luals.github.io/wiki/annotations#param)
 ]=]
 LUADOC_DESC_RETURN =
 [=[
@@ -837,7 +871,7 @@ function getFirstLast() end
 function getTags(item) end
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#return)
+[檢視文件](https://luals.github.io/wiki/annotations#return)
 ]=]
 LUADOC_DESC_FIELD =
 [=[
@@ -866,7 +900,7 @@ response = get("localhost")
 statusCode = response.status.code
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#field)
+[檢視文件](https://luals.github.io/wiki/annotations#field)
 ]=]
 LUADOC_DESC_GENERIC =
 [=[
@@ -922,7 +956,7 @@ local v = Generic("Foo") -- v is an object of Foo
 -- we give for key (K) or value (V)
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#generics-and-generic)
+[檢視文件](https://luals.github.io/wiki/annotations#generic)
 ]=]
 LUADOC_DESC_VARARG =
 [=[
@@ -940,7 +974,7 @@ LUADOC_DESC_VARARG =
 function concat(...) end
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#vararg)
+[檢視文件](https://luals.github.io/wiki/annotations#vararg)
 ]=]
 LUADOC_DESC_OVERLOAD =
 [=[
@@ -955,7 +989,7 @@ LUADOC_DESC_OVERLOAD =
 function table.insert(t, position, value) end
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#overload)
+[檢視文件](https://luals.github.io/wiki/annotations#overload)
 ]=]
 LUADOC_DESC_DEPRECATED =
 [=[
@@ -965,7 +999,7 @@ LUADOC_DESC_DEPRECATED =
 `---@deprecated`
 
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#deprecated)
+[檢視文件](https://luals.github.io/wiki/annotations#deprecated)
 ]=]
 LUADOC_DESC_META =
 [=[
@@ -980,7 +1014,7 @@ LUADOC_DESC_META =
 `---@meta`
 
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#meta)
+[檢視文件](https://luals.github.io/wiki/annotations#meta)
 ]=]
 LUADOC_DESC_VERSION =
 [=[
@@ -1005,7 +1039,7 @@ function onlyWorksInJIT() end
 function oldLuaOnly() end
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#version)
+[檢視文件](https://luals.github.io/wiki/annotations#version)
 ]=]
 LUADOC_DESC_SEE =
 [=[
@@ -1015,7 +1049,7 @@ LUADOC_DESC_SEE =
 `---@see <text>`
 
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#see)
+[檢視文件](https://luals.github.io/wiki/annotations#see)
 ]=]
 LUADOC_DESC_DIAGNOSTIC =
 [=[
@@ -1041,7 +1075,7 @@ local unused = "hello world"
 ---@diagnostic enable: unused-local
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#diagnostic)
+[檢視文件](https://luals.github.io/wiki/annotations#diagnostic)
 ]=]
 LUADOC_DESC_MODULE =
 [=[
@@ -1058,7 +1092,7 @@ local stringUtils
 local module = require('string.utils')
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#module)
+[檢視文件](https://luals.github.io/wiki/annotations#module)
 ]=]
 LUADOC_DESC_ASYNC =
 [=[
@@ -1068,7 +1102,7 @@ LUADOC_DESC_ASYNC =
 `---@async`
 
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#async)
+[檢視文件](https://luals.github.io/wiki/annotations#async)
 ]=]
 LUADOC_DESC_NODISCARD =
 [=[
@@ -1079,7 +1113,7 @@ LUADOC_DESC_NODISCARD =
 `---@nodiscard`
 
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#nodiscard)
+[檢視文件](https://luals.github.io/wiki/annotations#nodiscard)
 ]=]
 LUADOC_DESC_CAST =
 [=[
@@ -1114,7 +1148,7 @@ local x --> string|table
 print(x) --> table
 ```
 ---
-[檢視文件](https://github.com/LuaLS/lua-language-server/wiki/Annotations#cast)
+[檢視文件](https://luals.github.io/wiki/annotations#cast)
 ]=]
 LUADOC_DESC_OPERATOR = -- TODO: need translate!
 [=[
@@ -1149,7 +1183,7 @@ pB = -pA
 LUADOC_DESC_ENUM = -- TODO: need translate!
 [=[
 Mark a table as an enum. If you want an enum but can't define it as a Lua
-table, take a look at the [`@alias`](https://github.com/LuaLS/lua-language-server/wiki/Annotations#alias)
+table, take a look at the [`@alias`](https://luals.github.io/wiki/annotations#alias)
 tag.
 
 ## Syntax
@@ -1173,6 +1207,33 @@ local function setColor(color) end
 setColor(colors.green)
 ```
 ]=]
+LUADOC_DESC_SOURCE = -- TODO: need translate!
+[=[
+Provide a reference to some source code which lives in another file. When
+searching for the defintion of an item, its `@source` will be used.
+
+## Syntax
+`@source <path>`
+
+## Usage
+```
+---You can use absolute paths
+---@source C:/Users/me/Documents/program/myFile.c
+local a
+
+---Or URIs
+---@source file:///C:/Users/me/Documents/program/myFile.c:10
+local b
+
+---Or relative paths
+---@source local/file.c
+local c
+
+---You can also include line and char numbers
+---@source local/file.c:10:8
+local d
+```
+]=]
 LUADOC_DESC_PACKAGE = -- TODO: need translate!
 [=[
 Mark a function as private to the file it is defined in. A packaged function
