@@ -1,12 +1,11 @@
 ---@class vm
 local vm        = require 'vm.vm'
 local util      = require 'utility'
-local compiler  = require 'vm.compiler'
 local guide     = require 'parser.guide'
 
 local searchByNodeSwitch = util.switch()
     : case 'global'
-    ---@param global vm.node.global
+    ---@param global vm.global
     : call(function (suri, global, pushResult)
         for _, set in ipairs(global:getSets(suri)) do
             pushResult(set)
@@ -16,11 +15,28 @@ local searchByNodeSwitch = util.switch()
         pushResult(source)
     end)
 
-local function searchByNode(source, pushResult)
+local function searchByLocalID(source, pushResult)
+    local fields = vm.getVariableFields(source, true)
+    if fields then
+        for _, field in ipairs(fields) do
+            pushResult(field)
+        end
+    end
+end
+
+local function searchByNode(source, pushResult, mark)
+    mark = mark or {}
+    if mark[source] then
+        return
+    end
+    mark[source] = true
     local uri = guide.getUri(source)
-    compiler.compileByParentNode(source, nil, function (field)
+    vm.compileByParentNode(source, vm.ANY, function (field)
         searchByNodeSwitch(field.type, uri, field, pushResult)
     end)
+    vm.compileByNodeChain(source, function (src)
+        searchByNode(src, pushResult, mark)
+    end)
 end
 
 ---@param source parser.object
@@ -36,6 +52,7 @@ function vm.getFields(source)
         end
     end
 
+    searchByLocalID(source, pushResult)
     searchByNode(source, pushResult)
 
     return results
